async function recognize(base64, lang, options) {
    const { config, utils } = options;
    const { tauriFetch: fetch } = utils;
    let { model = "gpt-4o", apiKey, requestPath, customPrompt } = config;

    // 檢查是否是 Google API
    const isGoogleAPI = requestPath?.includes('generativelanguage.googleapis.com');
    
    if (isGoogleAPI) {
        // Google Gemini API 格式
        if (!model || model === "gpt-4o") {
            model = "gemini-1.5-flash";
        }
        
        const headers = {
            'Content-Type': 'application/json'
        }

        // 使用正確的 Google API endpoint
        requestPath = `https://generativelanguage.googleapis.com/v1beta/models/${model}:generateContent`;

        const body = {
            contents: [{
                role: "user",
                parts: [
                    {
                        text: customPrompt || "Just recognize the text in the image. Do not offer unnecessary explanations."
                    },
                    {
                        inlineData: {
                            mimeType: "image/png",
                            data: base64
                        }
                    }
                ]
            }]
        };

        // 添加 API key 到 URL
        requestPath += `?key=${apiKey}`;

        let res = await fetch(requestPath, {
            method: 'POST',
            url: requestPath,
            headers: headers,
            body: {
                type: "Json",
                payload: body
            },
            responseType: 1
        });

        // 處理 Google API 的返回格式
        if (res.ok) {
            let result = res.data;
            return result.candidates[0].content.parts[0].text;
        }

    } else {
        // OpenAI API 處理邏輯
        if (!requestPath) {
            requestPath = "https://api.openai.com";
        }
        if (!/https?:\/\/.+/.test(requestPath)) {
            requestPath = `https://${requestPath}`;
        }
        if (requestPath.endsWith('/')) {
            requestPath = requestPath.slice(0, -1);
        }
        if (!requestPath.endsWith('/chat/completions')) {
            requestPath += '/v1/chat/completions';
        }
        if (!customPrompt) {
            customPrompt = "Just recognize the text in the image. Do not offer unnecessary explanations.";
        }else{
            customPrompt = customPrompt.replaceAll("$lang", lang);
        }

        const headers = {
            'Content-Type': 'application/json',
            'Authorization': `Bearer ${apiKey}`
        }

        const body = {
            model,
            messages: [
                {
                    "role": "user", 
                    "content": [
                        {
                            "type": "text",
                            "text": customPrompt
                        },
                        {
                            "type": "image_url",
                            "image_url": {
                                "url": `data:image/png;base64,${base64}`,
                                "detail": "high"
                            }
                        }
                    ]
                }
            ]
        };

        let res = await fetch(requestPath, {
            method: 'POST',
            url: requestPath,
            headers: headers,
            body: {
                type: "Json",
                payload: body
            },
            responseType: 1
        });

        /* Debug 相關代碼
        const debugBody = { ...body };
        if (debugBody.messages?.[0]?.content) {
            debugBody.messages[0].content = debugBody.messages[0].content.map(item => {
                if (item.type === 'image_url') {
                    return { 
                        type: 'image_url', 
                        image_url: { 
                            url: '***[BASE64]***',
                            detail: item.image_url.detail 
                        } 
                    };
                }
                return item;
            });
        }
        */

        if (res.ok) {
            let result = res.data;
            if (!result || !result.choices || !result.choices[0]) {
                throw `Invalid API Response: ${JSON.stringify(result)}`;
            }
            
            const choice = result.choices[0];
            let content = '';
            if (choice.message && choice.message.content) {
                content = choice.message.content;
            } else if (choice.content) {
                content = choice.content;
            } else {
                content = JSON.stringify(choice);
            }

            /* Debug 相關代碼
            return `🔍 Debug Info:
Request URL: ${requestPath}
Request Headers: ${JSON.stringify(headers, null, 2)}
Request Body: ${JSON.stringify(debugBody, null, 2)}

📝 Response:
${content}`;
            */
            return content;
        } else {
            /* Debug 相關代碼
            throw `❌ Http Request Error
URL: ${requestPath}
Status: ${res.status}
Headers: ${JSON.stringify(headers, null, 2)}
Request Body: ${JSON.stringify(debugBody, null, 2)}
Response: ${JSON.stringify(res.data, null, 2)}`;
            */
            throw `Request failed with status ${res.status}`;
        }
    }
}
